==> webgui_7.6.27.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/AdSpace.pm <==
package WebGUI::i18n::English::AdSpace; 
use strict;

our $I18N = { 

	'macro code prompt' => {
		message => q|Use this code to place this ad space:|,
		lastUpdated => 0,
		context => q|this is a label for the output of macro code that the user can use to place his/her ad space|
	},

	'border color' => {
		message => q|Border Color|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'border color help' => {
		message => q|The hex value of the color of the border to be used around this text ad.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'text color' => {
		message => q|Text Color|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'text color help' => {
		message => q|The hex value of the color of the text in this text ad.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'background color' => {
		message => q|Background Color|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'background color help' => {
		message => q|The hex value of the color of the background in this text ad.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'url' => {
		message => q|URL|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'url help' => {
		message => q|The URL to which this ad will link. Note that this won't be used for Rich Media ads.|,
		lastUpdated => 1165511641,
		context => q|help for a form property in the ad editor|
	},

	'image help' => {
		message => q|The image file that will be displayed on each ad impression.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'rich help' => {
		message => q|Place the code here that will be used to generate the ad to be displayed.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'priority' => {
		message => q|Priority|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'priority help' => {
		message => q|A scaling mechanism to determine how often an ad should be displayed. The lower this number the more often it will be displayed. This really has no affect low traffic sites. If ad A has a priority of 0 and ad B has a priority of 10, and the site averages about one impression per second then ad A will be displayed roughly 100 times more frequently than ad B. Note that since this property is a scaling mechanism, it is not an exact ratio. The heavier the traffic is on the site, the more impact priority has.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'ad text' => {
		message => q|Ad Text|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'ad text help' => {
		message => q|Please type up to 255 characters of text that you'd like to see appear in this ad. Keep in mind that depending upon the size of your ad, the whole amount of text may not be seen if it's long. We recommend keeping it to 60 characters or less.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'type' => {
		message => q|Type|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'type help' => {
		message => q|What kind of ad are we running?|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'text' => {
		message => q|Text|,
		lastUpdated => 0,
		context => q|a type of ad that is text only|
	},

	'image' => {
		message => q|Image|,
		lastUpdated => 0,
		context => q|a type of ad that displays a banner image|
	},

	'rich' => {
		message => q|Rich Media|,
		lastUpdated => 0,
		context => q|a type of ad that contains javascript, flash, html forms, or some other rich media|
	},

	'ad id' => {
		message => q|Ad Id|,
		lastUpdated => 0,
	},

	'edit this ad space' => {
		message => q|Edit this ad space.|,
		lastUpdated => 0,
		context => q|a menu label for manageing ad spaces|
	},

	'manage ad spaces' => {
		message => q|Manage ad spaces.|,
		lastUpdated => 0,
		context => q|a menu label for manageing ad spaces|
	},

	'add an ad' => {
		message => q|Add an ad.|,
		lastUpdated => 0,
		context => q|a menu label for adding a new advertisement|
	},

	'used' => {
		message => q|Used|,
		lastUpdated => 0,
		context => q|the number of impressions displayed or clicks will be displayed after this label|
	},

	'is active' => {
		message => q|Is active?|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'is active help' => {
		message => q|Should this ad be included in the rotation?|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'clicks bought' => {
		message => q|Clicks Purchased|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'clicks bought help' => {
		message => q|How many clicks has the advertiser purchased? If they purchased a number of impressions you can leave this at zero.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'impressions bought' => {
		message => q|Impressions Purchased|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'impressions bought help' => {
		message => q|How many impressions (individual displays of the ad) has the advertiser purchased? If they purchased a number of clicks you can leave this at zero.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'edit advertisement' => {
		message => q|Edit Advertisement|,
		lastUpdated => 0,
		context => q|title of ad space edit screen|
	},

	'edit ad space' => {
		message => q|Edit Ad Space|,
		lastUpdated => 0,
		context => q|title of ad space edit screen|
	},

	'ad space id' => {
		message => q|Ad Space Id|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'name' => {
		message => q|Name|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'name help' => {
		message => q|This string is used in combination with the AdSpace macro to place ads on the site. It should contain no spaces and only alpha-numeric characters.|,
		lastUpdated => 1165511561,
		context => q|help for a form property in the ad manager|
	},

	'description' => {
		message => q|Description|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'description help' => {
		message => q|A full description of where this ad space will be located on the site.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad manager|
	},

	'title' => {
		message => q|Title|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'title help' => {
		message => q|A human readable label.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad manager|
	},

	'height' => {
		message => q|Height|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'height help' => {
		message => q|How tall (in pixels) should the ad space be.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad manager|
	},

	'width' => {
		message => q|Width|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'width help' => {
		message => q|How wide (in pixels) should the ad space be.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad manager|
	},

	'confirm ad space delete' => {
		message => q|Are you certain you want to delete this ad space and all the ads attached to it?|,
		lastUpdated => 0,
		context => q|menu item in ad manager|
	},

	'confirm ad delete' => {
		message => q|Are you certain you want to delete this ad?|,
		lastUpdated => 0,
		context => q|Message to confirm deletion of an ad in an ad space|
	},

	'add ad space' => {
		message => q|Add ad space.|,
		lastUpdated => 0,
		context => q|menu item in ad manager|
	},

	'topicName' => {
		message => q|Advertising|,
		lastUpdated => 0,
	},

	'add ad space body' => {
		message => q|<p>This screen provides you with a list of all ad spaces that have been created in WebGUI.  The icons next to each ad space allow you to edit or delete an ad space.  There is also a link on the screen to add new ad spaces.</p>|,
		lastUpdated => 0,
	},

        'error heading'  => {
            message     => q{There was an error with your Ad Space:},
            lastUpdated => 0,
        },

        'error invalid characters' => {
            message     => q{There are invalid characters in the title field. Please use only letters, numbers, and spaces.},
            lastUpdated => 0,
        },

};

1;

==> webgui_7.7.30.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/AdSpace.pm <==
package WebGUI::i18n::English::AdSpace; 
use strict;

our $I18N = { 

	'macro code prompt' => {
		message => q|Use this code to place this ad space:|,
		lastUpdated => 0,
		context => q|this is a label for the output of macro code that the user can use to place his/her ad space|
	},

	'border color' => {
		message => q|Border Color|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'border color help' => {
		message => q|The hex value of the color of the border to be used around this text ad.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'text color' => {
		message => q|Text Color|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'text color help' => {
		message => q|The hex value of the color of the text in this text ad.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'background color' => {
		message => q|Background Color|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'background color help' => {
		message => q|The hex value of the color of the background in this text ad.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'url' => {
		message => q|URL|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'url help' => {
		message => q|The URL to which this ad will link. Note that this won't be used for Rich Media ads.|,
		lastUpdated => 1165511641,
		context => q|help for a form property in the ad editor|
	},

	'image help' => {
		message => q|The image file that will be displayed on each ad impression.  To replace an existing image, simply upload a new one.|,
		lastUpdated => 1251431251,
		context => q|help for a form property in the ad editor|
	},

	'rich help' => {
		message => q|Place the code here that will be used to generate the ad to be displayed.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'priority' => {
		message => q|Priority|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'priority help' => {
		message => q|A scaling mechanism to determine how often an ad should be displayed. The lower this number the more often it will be displayed. This really has no affect low traffic sites. If ad A has a priority of 0 and ad B has a priority of 10, and the site averages about one impression per second then ad A will be displayed roughly 100 times more frequently than ad B. Note that since this property is a scaling mechanism, it is not an exact ratio. The heavier the traffic is on the site, the more impact priority has.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'ad text' => {
		message => q|Ad Text|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'ad text help' => {
		message => q|Please type up to 255 characters of text that you'd like to see appear in this ad. Keep in mind that depending upon the size of your ad, the whole amount of text may not be seen if it's long. We recommend keeping it to 60 characters or less.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'type' => {
		message => q|Type|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'type help' => {
		message => q|What kind of ad are we running?|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'text' => {
		message => q|Text|,
		lastUpdated => 0,
		context => q|a type of ad that is text only|
	},

	'image' => {
		message => q|Image|,
		lastUpdated => 0,
		context => q|a type of ad that displays a banner image|
	},

	'rich' => {
		message => q|Rich Media|,
		lastUpdated => 0,
		context => q|a type of ad that contains javascript, flash, html forms, or some other rich media|
	},

	'ad id' => {
		message => q|Ad Id|,
		lastUpdated => 0,
	},

	'edit this ad space' => {
		message => q|Edit this ad space.|,
		lastUpdated => 0,
		context => q|a menu label for manageing ad spaces|
	},

	'manage ad spaces' => {
		message => q|Manage ad spaces.|,
		lastUpdated => 0,
		context => q|a menu label for manageing ad spaces|
	},

	'add an ad' => {
		message => q|Add an ad.|,
		lastUpdated => 0,
		context => q|a menu label for adding a new advertisement|
	},

	'used' => {
		message => q|Used|,
		lastUpdated => 0,
		context => q|the number of impressions displayed or clicks will be displayed after this label|
	},

	'is active' => {
		message => q|Is active?|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'is active help' => {
		message => q|Should this ad be included in the rotation?|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'clicks bought' => {
		message => q|Clicks Purchased|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'clicks bought help' => {
		message => q|How many clicks has the advertiser purchased? If they purchased a number of impressions you can leave this at zero.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'impressions bought' => {
		message => q|Impressions Purchased|,
		lastUpdated => 0,
		context => q|a form property in the ad editor|
	},

	'impressions bought help' => {
		message => q|How many impressions (individual displays of the ad) has the advertiser purchased? If they purchased a number of clicks you can leave this at zero.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad editor|
	},

	'edit advertisement' => {
		message => q|Edit Advertisement|,
		lastUpdated => 0,
		context => q|title of ad space edit screen|
	},

	'edit ad space' => {
		message => q|Edit Ad Space|,
		lastUpdated => 0,
		context => q|title of ad space edit screen|
	},

	'ad space id' => {
		message => q|Ad Space Id|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'name' => {
		message => q|Name|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'name help' => {
		message => q|This string is used in combination with the AdSpace macro to place ads on the site. It should contain no spaces and only alpha-numeric characters.|,
		lastUpdated => 1165511561,
		context => q|help for a form property in the ad manager|
	},

	'description' => {
		message => q|Description|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'description help' => {
		message => q|A full description of where this ad space will be located on the site.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad manager|
	},

	'title' => {
		message => q|Title|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'title help' => {
		message => q|A human readable label.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad manager|
	},

	'height' => {
		message => q|Height|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'height help' => {
		message => q|How tall (in pixels) should the ad space be.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad manager|
	},

	'width' => {
		message => q|Width|,
		lastUpdated => 0,
		context => q|a form property in the ad manager|
	},

	'width help' => {
		message => q|How wide (in pixels) should the ad space be.|,
		lastUpdated => 0,
		context => q|help for a form property in the ad manager|
	},

	'confirm ad space delete' => {
		message => q|Are you certain you want to delete this ad space and all the ads attached to it?|,
		lastUpdated => 0,
		context => q|menu item in ad manager|
	},

	'confirm ad delete' => {
		message => q|Are you certain you want to delete this ad?|,
		lastUpdated => 0,
		context => q|Message to confirm deletion of an ad in an ad space|
	},

	'add ad space' => {
		message => q|Add ad space.|,
		lastUpdated => 0,
		context => q|menu item in ad manager|
	},

	'topicName' => {
		message => q|Advertising|,
		lastUpdated => 0,
	},

	'add ad space body' => {
		message => q|<p>This screen provides you with a list of all ad spaces that have been created in WebGUI.  The icons next to each ad space allow you to edit or delete an ad space.  There is also a link on the screen to add new ad spaces.</p>|,
		lastUpdated => 0,
	},

        'error heading'  => {
            message     => q{There was an error with your Ad Space:},
            lastUpdated => 0,
        },

        'error invalid characters' => {
            message     => q{There are invalid characters in the title field. Please use only letters, numbers, and spaces.},
            lastUpdated => 0,
        },

};

1;
